@@ -18,6 +18,8 @@ class SikuliXImagePath(SikuliXJClass):
     def imagePath_add(self, path):
         '''
         Used usually in any suite setup. Will add to SikuliX ImagePath a new directory where to find reference images
+        Note: paths must be specified using the correct path separators (slash on Mac and Unix and double blackslashes 
+        on Windows). In Robot Framework you can use the `${/}` construct as universal separator.
         
         | ImagePath Add | path |
         '''
@@ -32,9 +34,20 @@ class SikuliXImagePath(SikuliXJClass):
         '''
         SikuliXJClass.ImagePath.remove(path)
             
+    @keyword
+    def imagePath_reset(self):
+        '''
+        Will reset the SikuliX ImagePath and thereby remove all previous entries
+
+        | ImagePath Reset | 
+        '''
+        SikuliXJClass.ImagePath.reset()
+            
     @keyword
     def imagePath_dump(self):
-        imgPath = list(SikuliXJClass.ImagePath.get())
+        '''
+        Retrieves the full list of image paths and logs these as trace messagesin the log file.
+        '''
+        imgPath = list(SikuliXJClass.ImagePath.getPaths())
         for p in imgPath:
-            #print("Image PATH: " + str(p))
             logger.trace("Image PATH: " + str(p))
