@@ -28,7 +28,7 @@ class SikuliXLogger():
         '''
         Used to set the directory where to save the screenshots for the log file
 
-        | Set Sikuli resultDir | path |
+        | Set Sikuli ResultDir | path |
         '''
         SikuliXLogger.resultDir = path
 
@@ -37,7 +37,7 @@ class SikuliXLogger():
         '''
         Enable or disable logging of the images when keyword passes
 
-        | Set passedLogImages | ${True} |
+        | Set PassedLogImages | ${True} |
         '''
         scr = self.passedLogImages
         self.passedLogImages = mode
@@ -48,7 +48,7 @@ class SikuliXLogger():
         '''
         Enable or disable logging of the images when keyword fails
 
-        | Set failedLogImages | ${True} |
+        | Set FailedLogImages | ${True} |
         '''
         scr = self.failedLogImages
         self.failedLogImages = mode
@@ -59,7 +59,7 @@ class SikuliXLogger():
         '''
         Enable or disable logging of the images when the image is not found (for keywords that does not throw exception)
 
-        | Set notFoundLogImages | ${True} |
+        | Set NotFoundLogImages | ${True} |
         '''
         scr = self.notFoundLogImages
         self.notFoundLogImages = mode
@@ -75,10 +75,17 @@ class SikuliXLogger():
         logger.warn("WARNING: %s" % msg)
 
     @not_keyword
-    def _screenshot(self, folder="/screenshots/", region=(0, 0, 1920, 1080)):
+    def _screenshot(self, folder="/screenshots/", region=None):
         # generate unique name for screenshot filename
+        if region == None:
+            #br = SikuliXJClass.Screen().getBottomRight()
+            #region = (0, 0, br.x, br.y)
+            x = SikuliXJClass.Screen().getW()
+            y = SikuliXJClass.Screen().getH()
+            region = (0, 0, x, y)
+            logger.trace('Screenshot Size {}  {}'.format(x, y))
+        
         name = datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S-%f') + ".png"
-
         img_src = str(self.appScreen.capture(*region).getFile())
         full_folder = SikuliXLogger.resultDir + folder
 
@@ -95,7 +102,7 @@ class SikuliXLogger():
         return full_folder + name
 
     @not_keyword
-    def _passed(self, msg):
+    def _passed(self, msg, mode=None):
         libLogger.debug('PASS %s' % msg)
         logger.info('PASS: ' + msg)
 
@@ -105,12 +112,13 @@ class SikuliXLogger():
         score: float = float(last_match.getScore())
 
         if self.passedLogImages:
-            # source image
-            src_img: str = str(self.appPattern.getFilename())
-
-            # get relative path from result directory (log.html)
-            rel_path = relpath(src_img, SikuliXLogger.resultDir)
-            logger.debug('Source Image: <img src="%s" />' % rel_path, True)
+            if mode == None:
+                # source image
+                src_img: str = str(self.appPattern.getFilename())
+    
+                # get relative path from result directory (log.html)
+                rel_path = relpath(src_img, SikuliXLogger.resultDir)
+                logger.debug('Source Image: <img src="%s" />' % rel_path, True)
 
             # screenshot of matched image
             region = (last_match.getX(), last_match.getY(), last_match.getW(), last_match.getH())
@@ -121,44 +129,46 @@ class SikuliXLogger():
         logger.info("Matched with score: %s" % score)
 
     @not_keyword
-    def _failed(self, msg, seconds):
+    def _failed(self, msg, seconds, mode=None):
         libLogger.debug('FAIL %s' % msg)
         logger.error('FAIL: ' + msg)
 
         if self.failedLogImages:
-            # source image
-            src_img: str = str(self.appPattern.getFilename())
-            rel_path = relpath(src_img, SikuliXLogger.resultDir)
-            logger.info('Source Image: <img src="%s" />' % rel_path, True, True)
-
+            if mode == None:
+                # source image
+                src_img: str = str(self.appPattern.getFilename())
+                rel_path = relpath(src_img, SikuliXLogger.resultDir)
+                logger.info('Source Image: <img src="%s" />' % rel_path, True, True)
+    
             # screenshot
-            region = (0, 0, 1920, 1080)
-            name = self._screenshot("/screenshots/", region)
+            name = self._screenshot("/screenshots/")
             rel_path = relpath(name, SikuliXLogger.resultDir)
             logger.info('No Match: <img src="%s" />' % rel_path, True, True)
-        
-        wait: float = float(self.appRegion.getAutoWaitTimeout())
-        if seconds > 0:
-            wait: float = seconds
-        logger.debug('Image not visible after ' + str(wait) + ' seconds')
+
+        if mode == None:        
+            wait: float = float(self.appRegion.getAutoWaitTimeout())
+            if seconds > 0:
+                wait: float = seconds
+            logger.debug('Image not visible after ' + str(wait) + ' seconds')
         raise Exception(msg)
 
     @not_keyword
-    def _notfound(self, msg, seconds):
+    def _notfound(self, msg, seconds, mode=None):
         libLogger.debug('NOT FOUND %s' % msg)
         if self.notFoundLogImages:
-            # source image
-            src_img: str = str(self.appPattern.getFilename())
-            rel_path = relpath(src_img, SikuliXLogger.resultDir)
-            logger.info('Source Image: <img src="%s" />' % rel_path, True, True)
-
+            if mode == None:
+                # source image
+                src_img: str = str(self.appPattern.getFilename())
+                rel_path = relpath(src_img, SikuliXLogger.resultDir)
+                logger.info('Source Image: <img src="%s" />' % rel_path, True, True)
+    
             # screenshot
-            region = (0, 0, 1920, 1080)
-            name = self._screenshot("/screenshots/", region)
+            name = self._screenshot("/screenshots/")
             rel_path = relpath(name, SikuliXLogger.resultDir)
             logger.info('Not Found: <img src="%s" />' % rel_path, True, True)
         
-        wait: float = float(self.appRegion.getAutoWaitTimeout())
-        if seconds > 0:
-            wait: float = seconds
-        logger.debug('Image not visible after ' + str(wait) + ' seconds')
+        if mode == None:
+            wait: float = float(self.appRegion.getAutoWaitTimeout())
+            if seconds > 0:
+                wait: float = seconds
+            logger.debug('Image not visible after ' + str(wait) + ' seconds')
