@@ -2,6 +2,9 @@
 
 from .sikulixjclass import *
 
+if not useJpype:
+    from .sikulixpy4j import *
+    
 
 class SikuliXSettings(SikuliXJClass):
     '''
@@ -19,25 +22,32 @@ class SikuliXSettings(SikuliXJClass):
         | | ThrowException | boolean | true | Throw FindFailed exception |
         | | WheelNatural | boolean | true | Setting to false reverses the wheel direction |
         | | checkMousePosition | boolean | true | Setting to false supresses error message in RobotDesktop |
-        | | ActionLogs | boolean | true | - |
-        | | InfoLogs | boolean | true | - |
-        | | DebugLogs | boolean | false | - |
+        | | ActionLogs | boolean | true | Switched to show or hide the respective action message in the log file |
+        | | InfoLogs | boolean | true | Switched to show or hide the respective info message type in the  file |
+        | | DebugLogs | boolean | false | Switched to show or hide the respective debug message in the log file |
         | | ProfileLogs | boolean | false | - |
         | | TraceLogs | boolean | false | - |
         | | LogTime | boolean | false | - |
         | *Timing* |
         | | AutoWaitTimeout | float | 3.0 | Timeout for Range Wait operations in seconds |
-        | | WaitScanRate | float | 3.0 | Rate of rechecking in Range Wait operations, checks per second |
-        | | ObserveScanRate | float | 3.0 | - |
+        | | WaitScanRate | float | 3.0 | Specify the number of times actual search operations are performed per \
+            second while waiting for a pattern to appear or vanish. |
+        | | ObserveScanRate | float | 3.0 |  Specify the number of times actual search operations are performed per \
+            second while waiting for a pattern to appear or vanish. |
         | | RepeatWaitTime | int | 1 | Seconds for visual to vanish after action |
         | | DelayBeforeMouseDown | double | 0.3 | Delay time for mouse interaction | 
-        | | DelayAfterDrag | double | 0.3 | Delay time for mouse interaction | 
+        | | DelayAfterDrag | double | 0.3 | Specifies the waiting time after mouse down at the source location \
+            as a decimal value (seconds). | 
         | | DelayBeforeDrag | double | -0.3 | Delay time for mouse interaction | 
-        | | DelayBeforeDrop | double | 0.3 | Delay time for mouse interaction | 
+        | | DelayBeforeDrop | double | 0.3 | Specifies the waiting time before mouse up at the target location \
+            as a decimal value (seconds). | 
         | | TypeDelay | double | 0.0 | Delay time between two characters, must be < 1 second | 
-        | | ClickDelay | double | 0.0 | Delay time between two mouse down and mouse up, must be < 1 second | 
-        | | SlowMotionDelay | float | 2.0 | - | 
-        | | MoveMouseDelay | float | 0.5 | - | 
+        | | ClickDelay | double | 0.0 | Delay time between two mouse down and mouse up, must be < 1 second. \
+            Note: ClickDelay is reset to 0.0 on every mouse click | 
+        | | SlowMotionDelay | float | 2.0 | Control the duration of the visual effect (seconds). | 
+        | | MoveMouseDelay | float | 0.5 | Control the time taken for mouse movement to a target location by \
+            setting this value to a decimal value (default 0.5). The unit is seconds. Setting it to 0 will \
+            switch off any animation (the mouse will “jump” to the target location). | 
         | *Show Actions* |
         | | ShowActions | boolean | false | Use `setShowActions` to change the value of this setting |
         | | Highlight | boolean | false | Highlight every match (show red rectangle around) |
@@ -61,8 +71,16 @@ class SikuliXSettings(SikuliXJClass):
             target = get_java_class(SikuliXJClass.Settings).getDeclaredField(variable)
 
         previous = target.get(None)
-        if str(target.getGenericType()) == 'float':
-            target.set(None, JFloat(value))
+        variable_type = str(target.getGenericType())
+        logger.trace('Setting {}({}) to {}'.format(variable, variable_type, value))
+        if variable_type == 'int':
+            target.set(None, JInt(value))
+        elif variable_type == 'float':
+            target.set(value, JFloat(value))
+        elif variable_type == 'double':
+            target.set(None, JDouble(value))
+        elif variable_type == 'boolean':
+            target.set(None, JBoolean(value))
         else:
             target.set(None, value)
 
@@ -97,6 +115,6 @@ class SikuliXSettings(SikuliXJClass):
         '''
         Return show action mode
         
-        | ${val} | Settings isShowAction |
+        | ${val} | Settings IsShowAction |
         '''
         return SikuliXJClass.Settings.isShowActions()
